@@ -3,9 +3,9 @@ package Pod::ProjectDocs;
 use strict;
 use warnings;
 
-our $VERSION = '0.48_002'; # TRIAL VERSION
+our $VERSION = '0.48_003'; # TRIAL VERSION
 
-use base qw/Class::Accessor::Fast/;
+use Moose;
 
 use File::Spec;
 use JSON;
@@ -15,17 +15,18 @@ use Pod::ProjectDocs::Parser;
 use Pod::ProjectDocs::CSS;
 use Pod::ProjectDocs::IndexPage;
 
-__PACKAGE__->mk_accessors(qw/managers components config/);
+has 'managers' => (
+    is => 'rw',
+);
+has 'components' => (
+    is => 'rw',
+);
+has 'config' => (
+    is => 'rw',
+);
 
-sub new {
-    my ($class, @args) = @_;
-    my $self  = bless { }, $class;
-    $self->_init(@args);
-    return $self;
-}
-
-sub _init {
-    my($self, %args) = @_;
+sub BUILDARGS {
+    my($class, %args) = @_;
 
     # set absolute path to 'outroot'
     $args{outroot} ||= File::Spec->curdir;
@@ -46,7 +47,13 @@ sub _init {
     $args{except} ||= [];
     $args{except} = [ $args{except} ] unless ref $args{except};
 
-    $self->config( Pod::ProjectDocs::Config->new(%args) );
+    $args{config} = Pod::ProjectDocs::Config->new(%args);
+
+    return \%args;
+}
+
+sub BUILD {
+    my $self = shift;
 
     $self->_setup_components();
     $self->_setup_managers();
@@ -171,15 +178,21 @@ sub _croak {
 1;
 __END__
 
+=encoding utf-8
+
 =head1 NAME
 
 Pod::ProjectDocs - generates CPAN like project documents from pod.
 
 =head1 SYNOPSIS
 
-    #!/usr/bin/perl -w
+    #!/usr/bin/perl
+
     use strict;
+    use warnings;
+
     use Pod::ProjectDocs;
+
     my $pd = Pod::ProjectDocs->new(
         libroot => '/your/project/lib/root',
         outroot => '/output/directory',
@@ -187,7 +200,7 @@ Pod::ProjectDocs - generates CPAN like project documents from pod.
     );
     $pd->gen();
 
-    #or use pod2projdocs on your shell
+    # or use pod2projdocs on your shell
     pod2projdocs -out /output/directory -lib /your/project/lib/root
 
 =head1 DESCRIPTION
@@ -199,11 +212,11 @@ for your projects. It also creates an optional index page.
 
 =over 4
 
-=item outroot
+=item C<outroot>
 
 output directory for the generated documentation.
 
-=item libroot
+=item C<libroot>
 
 your library's (source code) root directory.
 
@@ -221,27 +234,27 @@ or
         libroot => ['/path/to/lib1', '/path/to/lib2'],
     );
 
-=item title
+=item C<title>
 
 your project's name.
 
-=item desc
+=item C<desc>
 
 description for your project.
 
-=item index
+=item C<index>
 
 whether you want to create an index for all generated pages (0 or 1).
 
-=item lang
+=item C<lang>
 
 set this language as xml:lang (default 'en')
 
-=item forcegen
+=item C<forcegen>
 
 whether you want to generate HTML document even if source files are not updated (default is 0).
 
-=item except
+=item C<except>
 
 the files matches this regex won't be parsed.
 
@@ -280,8 +293,13 @@ L<Pod::Simple::XHTML>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright(C) 2005 by Lyo Kato
-Copyright(C) 2017 by Martin Gruner
+=over 4
+
+=item © 2005 by Lyo Kato
+
+=item © 2017 by Martin Gruner
+
+=back
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.5 or,
